;define different breeds of agents available in the model.
breed [governments government]
breed [businesses business]
breed [households household]
breed [monies money]
breed [persons person]
breed [goods good]

;define globals, globals are variables that can be used anywhere in the model after they are "set".
globals[
  startyear
  currentyear
  futureyear

  currenttax
  futuretax
  totaltaxchange
  taxflow

  totalxchange

  BNP
  originalBNP

  unemployment
  originalunemployment
]

;patches and agents can own different variables, they are defined below
turtles-own[partner]
monies-own[origin destination]
persons-own[origin destination]
goods-own[origin destination]

;setup is run only once, when the setup button is pressed in the graphical interface. It clears the model and then sets up the model.
to setup
  clear-all
  setup-patches
  setup-agents
  set startyear 2017
  set currentyear 2017
  set futureyear currentyear + 1
  set currenttax 407300
  set originalBNP 100
  set BNP originalBNP
  set originalunemployment 100
  set unemployment originalunemployment
  set tax 0
  set xx 0
end

;go runs indefinetly if the go-forever button is pressed. The code is run from top to bottom and then loops back to the start after the end.
to go
  update-flows
  update-view
  if(currentyear > startyear and currentyear = futureyear)[
    update-BNP
    update-unemployment
    set futuretax currenttax + (currenttax * (tax / 100))
    set currenttax futuretax
    set totaltaxchange totaltaxchange + tax
    set totalxchange totalxchange + xx
    set tax 0
    set xx 0
    set futureyear futureyear + 1
  ]
end

;this method updates the current BNP number if the tax variable is not equal to 0 (!= 0)
to update-BNP
  if(tax != 0)
  [
    if(tax > 0)
      [
        set BNP BNP + (tax * -1)
      ]
    if(tax < 0)
      [
        set BNP BNP + (abs tax * 1)
      ]
  ]
  if(xx != 0)
  [
    if(xx < 0)
      [
        set BNP BNP + (abs xx * -0.5)
      ]
    if(xx > 0)
      [
        set BNP BNP + (xx * 0.5)
      ]
  ]
end

;this method updates the current unemployment number if the tax variable is not equal to 0 (!= 0).
to update-unemployment
  if(tax != 0)
  [
    if(tax > 0)
      [
        set unemployment unemployment + (tax * 1)
      ]
    if(tax < 0)
      [
        set unemployment unemployment + (abs tax * -1)
      ]
  ]
  if(xx != 0)
  [
    if(xx < 0)
      [
        set unemployment unemployment + (abs xx * 1)
      ]
    if(xx > 0)
      [
        set unemployment unemployment + (xx * -1)
      ]
  ]
end

;this methods update the tax flow using the absolute value of the taxchange.
to update-flows
  ;update the taxflow, meaning how fast the agents actually moves
  if(totaltaxchange + totalxchange = 0)[
    set taxflow 0.001
  ]
  if(totaltaxchange + totalxchange > 0)[
    if(totaltaxchange + totalxchange < 5)[
          set taxflow 0.001 - (0.001 * ((totaltaxchange + totalxchange) * 20) / 100)
    ]
    if(totaltaxchange + totalxchange >= 5 and totaltaxchange + totalxchange < 50)[
          set taxflow 0.0002 - (0.0002 * ((totaltaxchange + totalxchange) * 2) / 100)
    ]
  ]
  if(totaltaxchange + totalxchange < 0)[
    if(totaltaxchange + totalxchange >= -10)[
          set taxflow 0.001 + (0.001 + (0.001 * ((( abs(totaltaxchange + totalxchange) * 20) / 100) - 1)))
    ]
    if(totaltaxchange + totalxchange < -10)[
          set taxflow 0.003 + (0.003 + (0.003 * ((( abs(totaltaxchange + totalxchange) * 1) / 100) - 1)))
    ]

  ]
end

;this method is the main method used in the model, it updates the view based on the view drop down menu in the interface.
;if the user selects the "Tax" view in the interface, the model visualizes the flow of money based on the current monetary policy.
;if the user selects the "unemployment" view in the interface, the model visualizes the flow of human resources based on the current monetary policy.
;       - People moving to the businesses are employed
;       - People moving to the state are unemployed
;if the user selects the "Goods" view in the interface, the model visualizes the flow of goods based on the current monetary policy.
to update-view

  if(view = "Tax")[
   ask persons[die]
   ask goods [die]

    if(BNP <= originalBNP)[
      ask monies with [destination = "households"][die]
      ask monies with [destination = "businesses"][die]
      ask monies with [destination = "government"][die]

      if(count monies with[origin = "households"] < count households)[
        ask households [hatch-monies 1 [set color green set size 2 set origin "households" set destination "goverenment"]]
      ]
      if(count monies with[origin = "businesses"] < count businesses)[
        ask businesses [hatch-monies 1 [set color green set size 2 set origin "businesses" set destination "goverenment"]]
      ]

      ask monies with [destination = "goverenment"][set heading towards one-of governments]
      ask monies [forward taxflow]
      ask monies with [destination = "goverenment"][if(count governments-here = 1)[die]]
    ]

   if(BNP > originalBNP)[
     ask monies with [origin = "households"][die]
     ask monies with [origin = "businesses"][die]
     ask monies with [destination = "government"][die]

     if(count monies with[destination = "households"] < 1)[
       ask governments [hatch-monies count households [set color green set size 2 set origin "government" set destination "households"]]
       ask monies with [destination = "households" and partner = 0][set partner one-of households with [partner = 0] ask partner[set partner myself]]
    ]
    if(count monies with[destination = "businesses"] < 1)[
      ask governments [hatch-monies count businesses[set color green set size 2 set origin "government" set destination "businesses"]]
      ask monies with [destination = "businesses" and partner = 0][set partner one-of businesses with [partner = 0] ask partner[set partner myself]]
    ]

     ask monies [set heading towards partner]

     ask monies [forward taxflow]
     ask monies [if([who] of partner = one-of [who] of turtles-here)[ask partner[set partner 0] die]]
   ]
  ]

  if(view = "Employment")[
    ask monies[die]
    ask goods[die]

    if(count persons with[origin = "households"] = 0)
    [
      ask turtles [set partner 0]
      ask households [hatch-persons 2 [set color white set size 1 set origin "households" set destination "businesses"]]
      if((originalunemployment - unemployment) / 100 >= 0)[
        ask(n-of (2 - ((originalunemployment - unemployment) / 2))persons with [destination = "businesses"]) [set destination "government"]
      ]
      if((originalunemployment - unemployment) / 100 < 0)[
        ask(n-of (2 - ((originalunemployment - unemployment) / 2))persons with [destination = "businesses"]) [set destination "government"]
      ]
      ask persons with [destination = "businesses"][set heading towards one-of businesses]
      ask persons with [destination = "government"][set heading towards one-of governments]
    ]

    ask persons [forward taxflow]
    ask persons with [destination = "businesses"][if(count businesses-here = 1)[die]]
    ask persons with [destination = "government"][if(count governments-here = 1)[die]]
  ]

   if(view = "Goods")[
    ask monies[die]
    ask persons[die]

    if(BNP <= originalBNP)[
      if(count goods = 0)[
        ask turtles [set partner  0]
        ask businesses [hatch-goods 2 [set color brown set size 1 set origin "businesses" set destination "households"]]
        ask(n-of ((count goods / 100) * (30 + ((abs totaltaxchange + abs totalxchange)  * 2)))goods with [destination = "households"])[set destination "overseas"]
      ]
      ask goods with [destination = "households" and partner = 0][set partner one-of households with [partner = 0] ask partner[set partner myself]]
      ask goods with[destination = "households"][set heading towards partner]
      ask goods with[destination = "overseas"][set heading towards patch 0 -15]

   ]

    if(BNP > originalBNP)[
      if(count goods = 0)[
        ask turtles [set partner 0]
        ask businesses [hatch-goods (((count households / 100) * 70) / count businesses)  [set color brown set size 1 set origin "businesses" set destination "households"]]
        ask patches with [pxcor = 0 and pycor = -15][sprout-goods ((count households / 100) * 30)[set color brown set size 1 set origin "businesses" set destination "households"]]
      ]
      ask goods with [destination = "households" and partner = 0][set partner one-of households with [partner = 0] ask partner[set partner myself]]
      ask goods with[destination = "households"][set heading towards partner]
    ]

    ask goods [forward taxflow]
    ask goods with[destination = "households"][if([who] of partner = one-of [who] of turtles-here)[ask partner[set partner 0] die]]
    ask goods with[destination = "overseas"][if(ycor < -14)[die]]
  ]
end

;this method is run during the setup of the model, and it draws the different areas of seen in the vizual part of the model.
to setup-patches
  ;setup goverenment area
  ask patches with [pxcor >= -16 and pxcor <= 16 and pycor > 9] [
    set pcolor orange]
  ask patches with [pxcor = 0 and pycor = 11][
    set plabel "Staten"]

  ;setup household area
  ask patches with [pxcor >= -16 and pxcor < 0 and pycor <= 9] [
    set pcolor green]
  ask patches with [pxcor = -11 and pycor = 6][
    set plabel "Husholdninger"]

  ;setup business area
  ask patches with [pxcor > 0 and pxcor <= 16 and pycor <= 9] [
    set pcolor blue]
  ask patches with [pxcor = 15 and pycor = 6][
    set plabel "Virksomheder"]

  ;setup neutral area
  ask patches with [pxcor = 0 and pycor > -12 and pycor <= 9] [
    set pcolor white]
  ask patches with [pxcor >= -16 and pxcor <= 16 and pycor = 9] [
    set pcolor white]
  ask patches with [pxcor >= -5 and pxcor <= 5 and pycor <= -11] [
    set pcolor white]

  ;setup ??? area
  ask patches with [pxcor >= -4 and pxcor <= 4 and pycor <= -12] [
    set pcolor black]
  ask patches with [pxcor = 0 and pycor = -15][
    set plabel "???"]
end

;this method sets up the different agents. It defines the shapes of potential agents and the spawns the initial agents into the world (government, houses and businesses).
to setup-agents
  ;define shapes for agents
  set-default-shape governments "building institution"
  set-default-shape businesses "factory"
  set-default-shape households "house efficiency"
  set-default-shape monies "dollar bill"
  set-default-shape persons "person"
  set-default-shape goods "box"

  ;create 1 government building at a specific coordinate
  create-governments 1 [set xcor 0 set ycor 14 set size 4 set color white]

  ;create 10 house at a random point in the green area
  create-households 10 [set color white set size 2.5]
  ask households [move-to one-of patches with [pcolor = green]]

  ;create 5 businesses at a random point in the blue area
  create-businesses 5 [set color white set size 3.5]
  ask businesses [move-to one-of patches with [pcolor = blue]]
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
647
448
-1
-1
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
142
10
208
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
142
43
208
76
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
209
449
647
482
tax
tax
-10
10
0.0
1
1
%
HORIZONTAL

MONITOR
140
112
210
157
Year
currentyear
17
1
11

BUTTON
120
77
210
110
Next year
set currentyear currentyear + 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
72
157
214
202
View
View
"Tax" "Employment" "Goods"
0

MONITOR
18
250
208
295
Total tax change in %
totaltaxchange
17
1
11

MONITOR
17
295
209
340
NIL
BNP
17
1
11

MONITOR
17
339
209
384
Unemployment
Unemployment
17
1
11

SLIDER
209
489
647
522
xx
xx
-10
10
0.0
1
1
%
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

building institution
false
0
Rectangle -7500403 true true 0 60 300 270
Rectangle -16777216 true false 130 196 168 256
Rectangle -16777216 false false 0 255 300 270
Polygon -7500403 true true 0 60 150 15 300 60
Polygon -16777216 false false 0 60 150 15 300 60
Circle -1 true false 135 26 30
Circle -16777216 false false 135 25 30
Rectangle -16777216 false false 0 60 300 75
Rectangle -16777216 false false 218 75 255 90
Rectangle -16777216 false false 218 240 255 255
Rectangle -16777216 false false 224 90 249 240
Rectangle -16777216 false false 45 75 82 90
Rectangle -16777216 false false 45 240 82 255
Rectangle -16777216 false false 51 90 76 240
Rectangle -16777216 false false 90 240 127 255
Rectangle -16777216 false false 90 75 127 90
Rectangle -16777216 false false 96 90 121 240
Rectangle -16777216 false false 179 90 204 240
Rectangle -16777216 false false 173 75 210 90
Rectangle -16777216 false false 173 240 210 255
Rectangle -16777216 false false 269 90 294 240
Rectangle -16777216 false false 263 75 300 90
Rectangle -16777216 false false 263 240 300 255
Rectangle -16777216 false false 0 240 37 255
Rectangle -16777216 false false 6 90 31 240
Rectangle -16777216 false false 0 75 37 90
Line -16777216 false 112 260 184 260
Line -16777216 false 105 265 196 265

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dollar bill
false
0
Rectangle -7500403 true true 15 90 285 210
Rectangle -1 true false 30 105 270 195
Circle -7500403 true true 120 120 60
Circle -7500403 true true 120 135 60
Circle -7500403 true true 254 178 26
Circle -7500403 true true 248 98 26
Circle -7500403 true true 18 97 36
Circle -7500403 true true 21 178 26
Circle -7500403 true true 66 135 28
Circle -1 true false 72 141 16
Circle -7500403 true true 201 138 32
Circle -1 true false 209 146 16
Rectangle -16777216 true false 64 112 86 118
Rectangle -16777216 true false 90 112 124 118
Rectangle -16777216 true false 128 112 188 118
Rectangle -16777216 true false 191 112 237 118
Rectangle -1 true false 106 199 128 205
Rectangle -1 true false 90 96 209 98
Rectangle -7500403 true true 60 168 103 176
Rectangle -7500403 true true 199 127 230 133
Line -7500403 true 59 184 104 184
Line -7500403 true 241 189 196 189
Line -7500403 true 59 189 104 189
Line -16777216 false 116 124 71 124
Polygon -1 true false 127 179 142 167 142 160 130 150 126 148 142 132 158 132 173 152 167 156 164 167 174 176 161 193 135 192
Rectangle -1 true false 134 199 184 205

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

factory
false
0
Rectangle -7500403 true true 76 194 285 270
Rectangle -7500403 true true 36 95 59 231
Rectangle -16777216 true false 90 210 270 240
Line -7500403 true 90 195 90 255
Line -7500403 true 120 195 120 255
Line -7500403 true 150 195 150 240
Line -7500403 true 180 195 180 255
Line -7500403 true 210 210 210 240
Line -7500403 true 240 210 240 240
Line -7500403 true 90 225 270 225
Circle -1 true false 37 73 32
Circle -1 true false 55 38 54
Circle -1 true false 96 21 42
Circle -1 true false 105 40 32
Circle -1 true false 129 19 42
Rectangle -7500403 true true 14 228 78 270

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

house efficiency
false
0
Rectangle -7500403 true true 180 90 195 195
Rectangle -7500403 true true 90 165 210 255
Rectangle -16777216 true false 165 195 195 255
Rectangle -16777216 true false 105 202 135 240
Polygon -7500403 true true 225 165 75 165 150 90
Line -16777216 false 75 165 225 165

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
